@@ -11,12 +11,14 @@ import (
 	"syscall"
 
 	"github.com/air-verse/air/runner"
+	"github.com/fatih/color"
 )
 
 var (
 	cfgPath     string
 	debugMode   bool
 	showVersion bool
+	colorMode   string
 	cmdArgs     map[string]runner.TomlInfo
 )
 
@@ -39,6 +41,7 @@ func parseFlag(args []string) {
 	flag.StringVar(&cfgPath, "c", "", "config path")
 	flag.BoolVar(&debugMode, "d", false, "debug mode")
 	flag.BoolVar(&showVersion, "v", false, "show version")
+	flag.StringVar(&colorMode, "color", "auto", "colored output: auto, always, never")
 	cmd := flag.CommandLine
 	cmdArgs = runner.ParseConfigFlag(cmd)
 	if err := flag.CommandLine.Parse(args); err != nil {
@@ -81,6 +84,16 @@ func printSplash() {
 }
 
 func main() {
+	switch colorMode {
+	case "always":
+		color.NoColor = false
+	case "never":
+		color.NoColor = true
+	case "auto", "":
+		// do nothing
+	default:
+		log.Fatal("unsupported color mode: use always, never, auto")
+	}
 	if showVersion {
 		printSplash()
 		return
