@@ -118,7 +118,7 @@ func TestConfPreprocess(t *testing.T) {
 		t.Fatalf("preprocess error %v", err)
 	}
 	suffix := "/_testdata/toml/tmp/main"
-	binPath := df.Build.Entrypoint.binary()
+	binPath := df.Build.Bin
 	if !strings.HasSuffix(binPath, suffix) {
 		t.Fatalf("bin path is %s, but not have suffix  %s.", binPath, suffix)
 	}
